@@ -20,9 +20,19 @@
 #ifndef __RSS_FORMATTER_H_
 #define __RSS_FORMATTER_H_
 
+#include <mail/e-mail-reader-utils.h>
+
 #include "debug.h"
 
 gchar *rss_process_feed(gchar *feed, guint len);
+gchar *rss_process_website(gchar *content, gchar *website);
+gboolean rss_get_current_view(void);
+void rss_set_current_view(gboolean value);
+gchar *rss_component_peek_base_directory(void);
+gboolean rss_get_changed_view(void);
+void rss_set_changed_view(gboolean value);
+gboolean rss_get_is_html(gchar *feedid);
+EMailDisplay *rss_get_display(void);
 
 #endif /*__RSS_FORMATTER_H_*/
 
